@@ -468,6 +468,64 @@ print.SurvivalAnalysisUnivariateResult <- function(x,
   invisible(x)
 }
 
+#' Print the essentials of a SurvivalAnalysisUnivariateResult.
+#'
+#' Write complete textual information for one or multiple survival
+#' analysis results in a text file.
+#'
+#' As write_survival takes potentially multiple objects, it cannot
+#' return its input in a cleanly defined way.
+#' You can still elegantly combine \code{write_survival} in a pipe followed by
+#' \code{\link{kaplan_meier_plot}} or \code{\link{kaplan_meier_grid}}
+#' for a single input object if you apply the
+#' tee pipe operator \code{\%T>\%} in front of \code{write_survival}.
+#'
+#' @param ... Results generated by \code{\link{analyse_survival}},
+#'  or \code{\link{analyse_multivariate}}, or lists of such objects
+#' @param file A connection, or a character string naming the file to print to.
+#' (see \code{\link{cat}})
+#' @param label A label describing the result,
+#'    or a vector of the same size as results in ... (will then be mapped 1:1)
+#' @param p_precision,hr_precision,time_precision Precision with which to print floating point values
+#' @param include_end_separator Boolean:
+#'    Append "\\n---\\n" as separator?
+#'    Comes handy if printing multiple results following each other
+#' @param timespan_unit Unit for time spans: "days", "months" or "years"
+#'
+#' @return None (invisible NULL).
+#'
+#' @export
+write_survival <- function(...,
+                           file,
+                           label = NULL,
+                           p_precision = 3,
+                           hr_precision = 2,
+                           time_precision = 1,
+                           include_end_separator = FALSE,
+                           timespan_unit = c("days", "months", "years"))
+{
+  # take dots and splice bare lists
+  results <- flatten_if(list2(...), is_bare_list)
+  timespan_unit <- match.arg(timespan_unit)
+
+  if (is.null(label))
+  {
+    label <- list(NULL) # need to wrap for pmap
+  }
+
+  pmap(list(results,
+            label=label),
+       format,
+       p_precision = p_precision,
+       hr_precision = hr_precision,
+       time_precision = time_precision,
+       include_end_separator = include_end_separator,
+       timespan_unit = timespan_unit
+  ) %>%
+    str_c(collapse = "") %>%
+    cat(file = file)
+}
+
 # Takes the result of survival_analysis and formats
 # the essential information into a multi-line string, which is returned invisibly.
 #' Convenience formatting and printing of result
